pub struct Lexer<'input> {
inputs: &'input [Token],
inputs_index: usize,
loc: Loc,
iter: Peekable<CharIndices<'input>>,
brace_depth: usize,
in_calc: bool,
pending_line_ignores: Vec<IgnoreFilter>,
pending_block_ignores: Vec<IgnoreFilter>,
active_block_ignores: Vec<(usize, u32, IgnoreFilter)>,
active_range_ignores: Vec<(u32, IgnoreFilter)>,
}Expand description
An iterator that produces Lexeme values on demand.
Fields
inputs: &'input [Token]The input is in most cases a single token (a whole file), but when processing macros it can be a sequence of tokens from different locations. A specialized lexer for the whole-file case may be worth it for speed.
inputs_index: usizeThe current index into the inputs array.
loc: LocTracking file, line, and column of the current char.
iter: Peekable<CharIndices<'input>>Iterator over the current inputs token.
brace_depth: usizeHow many nested braces are around the current char. This is only used to warn about misaligned braces.
in_calc: boolIs the lexer inside a @[ calculation?
This restricts the chars allowed in identifiers.
pending_line_ignores: Vec<IgnoreFilter>Line-ignores targeting the next non-blank non-comment line.
pending_block_ignores: Vec<IgnoreFilter>Block-ignores targeting the next open brace.
active_block_ignores: Vec<(usize, u32, IgnoreFilter)>Track the brace depth and starting line of each open block-ignore. Kept sorted by ascending brace depth.
active_range_ignores: Vec<(u32, IgnoreFilter)>Track the nested begin/end ignore ranges.
Implementations
Sourceimpl<'input> Lexer<'input>
impl<'input> Lexer<'input>
pub fn new(inputs: &'input [Token]) -> Self
Sourcefn peek(&mut self) -> Option<(usize, char)>
fn peek(&mut self) -> Option<(usize, char)>
Return the current char and its offset in the current input.
Sourcefn eof_offset(&self) -> usize
fn eof_offset(&self) -> usize
Return the offset just beyond the final character in the input.
Sourcefn only_whitespace_left(&mut self) -> bool
fn only_whitespace_left(&mut self) -> bool
Destructively check if there are any non-whitespace characters between here and the end of the input.
Sourcefn apply_line_ignores(&mut self)
fn apply_line_ignores(&mut self)
Apply the pending line-ignores to the current line.
Sourcefn apply_block_ignores(&mut self)
fn apply_block_ignores(&mut self)
Apply the pending block-ignores to the current open brace.
Sourcefn close_block_ignores(&mut self)
fn close_block_ignores(&mut self)
Check which open block-ignores can now be closed and registered.